  function  colorbarv(pos,y,label,barunit,zeroline,density,boxcolor)

% function  colorbarv(pos,y,label,barunit,zeroline)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Generate a vertical colorbar when given a color scale x 
% and the location to place the colorbar. A vector for scale
% is also needed.
%
%   pos = [left_margin, bottom_margin, width, hight]
%         where to place, and the size of the color bar.
%
%   y = [-30:5:30]', tick (or color scale) of the color bar.
%       should be the same for the color scale of the figure.
%
%   label = [-30:10:30]', ticklabels of the color bar.
%
%   barunit = 'cm/s', or any other string in any length, 
%             it is placed on the color bar as y label to the 
%             right hand side.       
%
%   zeroline = 0, plot a black zero line
%            = others (default=NaN), do not plot this line.
%
%   density = 'density', apply a minus sign to the labels
%           = others (default='ordinary'), ordinary plot.
%
%   boxcolor = 'w', set the box, yticklabel & ylabel all in one color
%           = others (default='k').
%
% By Yonggang Liu, 2003.1.10
% Revised for density plot, 2003.6.5
% Revised for white color labels, 2012.1.27
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

 % lmargin = 1.2; bottom = 5.3; hwidth = .3; height = 5;
 % pos = [lmargin       bottom       hwidth height];
 % y = [17:0.5:30]';

if nargin <= 6
   boxcolor = 'k';
end

if nargin <= 5
   density = 'ordinary';
end

if nargin <= 4
   zeroline = NaN;
end
  

  [m,n] = size(y);
  if n~=1 & m==1
     y = y';
  end

 
  bar(:,1) = y;
  bar(:,2) = y;
  bar(:,3) = y;
  bar(:,4) = y;

  x = [1:4];

  ax2 = axes('position',pos); 
  
  [c,h] = contourf(x,y,bar,y,'w-');  hold on;
    set(h,'linestyle','none');
   % set(h,'linewidth',0.1);
  y0 = [min(y) max(y)];  caxis(y0);

  x1 = 1;
  x2 = 4;
  x0 = [x1 x2];

% Format the axes:
  set(ax2,'YAxisLocation','right');
  if strcmp(density,'density'),
    set(ax2,'ylim',y0,'ytick',label,'yticklabel',-label,'color',boxcolor);
  else
    set(ax2,'ylim',y0,'ytick',label,'yticklabel',label,'color',boxcolor);
  end
  set(ax2,'FontSize',10,'FontWeight','normal','color',boxcolor);

  H = ylabel(barunit);
  set(H,'FontSize',10,'color',boxcolor);
  % set(H,'FontSize',8,'FontWeight','bold');
 
  set(ax2,'xlim',x0,'xtick',[],'TickDir','in','Box','on');
 % set(ax2, 'Color', boxcolor);
  set(ax2, 'Color', boxcolor, 'XColor', boxcolor, 'YColor',boxcolor);

  if zeroline == 0
   % Plot a black zero line:
    h = plot([1 4],[0 0],'w-'); set(h,'linewidth',1); hold on;
  end

return;

